==> igniteui-react-16.16.2.tgz: package/esm2015/lib/Rating.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { NumberEventArgs } from "./NumberEventArgs";
/**
 * @hidden
 */
export let Rating = /*@__PURE__*/ (() => {
    class Rating extends BaseElement {
        constructor() {
            super(...arguments);
            this.d = new WCNativeHelper();
            this.l = null;
            this.change = null;
            this.hover = null;
        }
        get e() {
            return this.d;
        }
        get nativeElement() {
            return this.l;
        }
        set nativeElement(a) {
            this.l = a;
            this.d.d = this.l;
        }
        get i() {
            let ret_ = this.e.c("max");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.e.i("max", value_);
        }
        get j() {
            let ret_ = this.e.c("step");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.e.i("step", value_);
        }
        get p() {
            let ret_ = this.e.c("symbol");
            return ret_;
        }
        set p(a) {
            let value_ = a;
            this.e.i("symbol", value_);
        }
        get o() {
            let ret_ = this.e.c("name");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.e.i("name", value_);
        }
        get n() {
            let ret_ = this.e.c("label");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.e.i("label", value_);
        }
        get q() {
            let ret_ = this.e.c("valueFormat");
            return ret_;
        }
        set q(a) {
            let value_ = a;
            this.e.i("valueFormat", value_);
        }
        get k() {
            let ret_ = this.e.c("value");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.e.i("value", value_);
        }
        get f() {
            let ret_ = this.e.c("disabled");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.e.i("disabled", value_);
        }
        get g() {
            let ret_ = this.e.c("hoverPreview");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.e.i("hoverPreview", value_);
        }
        get h() {
            let ret_ = this.e.c("readonly");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.e.i("readonly", value_);
        }
        get c() {
            let ret_ = this.e.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.e.i("size", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.e.g("change", (a) => this.change(this, NumberEventArgs.a(a)));
            }
            else {
                this.e.h("change");
            }
        }
        hoverChanged() {
            if (this.hover != null) {
                this.e.g("hover", (a) => this.hover(this, NumberEventArgs.a(a)));
            }
            else {
                this.e.h("hover");
            }
        }
        u(a) {
            this.nativeElement.stepUp(a);
        }
        t(a) {
            this.nativeElement.stepDown(a);
        }
    }
    Rating.$t = /*@__PURE__*/ markType(Rating, 'Rating', BaseElement.$);
    return Rating;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/Rating.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { NumberEventArgs } from "./NumberEventArgs";
/**
 * @hidden
 */
export let Rating = /*@__PURE__*/ (() => {
    class Rating extends BaseElement {
        constructor() {
            super(...arguments);
            this.d = new WCNativeHelper();
            this.m = null;
            this.change = null;
            this.hover = null;
        }
        get e() {
            return this.d;
        }
        get nativeElement() {
            return this.m;
        }
        set nativeElement(a) {
            this.m = a;
            this.d.o = this.m;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get j() {
            let ret_ = this.e.n("max");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.e.v("max", value_);
        }
        get k() {
            let ret_ = this.e.n("step");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.e.v("step", value_);
        }
        get p() {
            let ret_ = this.e.n("name");
            return ret_;
        }
        set p(a) {
            let value_ = a;
            this.e.v("name", value_);
        }
        get o() {
            let ret_ = this.e.n("label");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.e.v("label", value_);
        }
        get q() {
            let ret_ = this.e.n("valueFormat");
            return ret_;
        }
        set q(a) {
            let value_ = a;
            this.e.v("valueFormat", value_);
        }
        get l() {
            let ret_ = this.e.n("value");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.e.v("value", value_);
        }
        get f() {
            let ret_ = this.e.n("disabled");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.e.v("disabled", value_);
        }
        get g() {
            let ret_ = this.e.n("hoverPreview");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.e.v("hoverPreview", value_);
        }
        get h() {
            let ret_ = this.e.n("readonly");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.e.v("readonly", value_);
        }
        get i() {
            let ret_ = this.e.n("single");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.e.v("single", value_);
        }
        get c() {
            let ret_ = this.e.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.e.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("size", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.e.r("change", (a) => this.change(this, NumberEventArgs.a(a)));
            }
            else {
                this.e.u("change");
            }
        }
        hoverChanged() {
            if (this.hover != null) {
                this.e.r("hover", (a) => this.hover(this, NumberEventArgs.a(a)));
            }
            else {
                this.e.u("hover");
            }
        }
        v(a) {
            this.nativeElement.stepUp(this.e.i(a));
        }
        u(a) {
            this.nativeElement.stepDown(this.e.i(a));
        }
    }
    Rating.$t = /*@__PURE__*/ markType(Rating, 'Rating', BaseElement.$);
    return Rating;
})();
